@@ -13,7 +13,7 @@ use Cwd;
 use vars qw( $VERSION @ISA );
 
 BEGIN {
-    $VERSION = '1.34';
+    $VERSION = '1.35';
     @ISA     = qw( Archive::Zip );
 
     if ( $^O eq 'MSWin32' ) {
@@ -481,7 +481,7 @@ sub overwriteAs {
     }
 
     # move the temp to the original name (possibly copying)
-    unless ( File::Copy::move( $tempName, $zipName ) ) {
+    unless ( File::Copy::move( $tempName, $zipName ) || File::Copy::copy( $tempName, $zipName) ) {
         $err = $!;
         rename( $backupName, $zipName );
         unlink($tempName);
